##  Viewing Fact Sheet Details
To view fact sheet details:
  1. Open a diagram.
  2. Choose any fact sheet shape in the diagram.
The side panel opens with fact sheet information.
  3. Use the side panel to review fact sheet attributes and relations, assess data quality and completeness, and go to full fact sheet pages.


![Business Capability Map with side panel showing details for Production Management.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274852467a441014bac5add4c0dd187b_LowRes.png)
Viewing Fact Sheet Details in the Side Panel
**Note**
The side panel displays only the relations present in the diagram. It does not show all relations associated with the fact sheets. When you choose a fact sheet's name in the side panel, it opens in a new tab.
